==> squishyplanet-0.2.1.tar.gz: squishyplanet-0.2.1/README.md <==
# squishyplanet

[![DOI](https://joss.theoj.org/papers/10.21105/joss.06972/status.svg)](https://doi.org/10.21105/joss.06972)
[![Documentation Status](https://readthedocs.org/projects/squishyplanet/badge/?version=latest)](https://squishyplanet.readthedocs.io/en/latest/?badge=latest)
![Build Status](https://github.com/ben-cassese/squishyplanet/actions/workflows/tests.yml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/ben-cassese/squishyplanet/badge.svg?branch=main&service=github)](https://coveralls.io/github/ben-cassese/squishyplanet?branch=main)
![PyPI - Version](https://img.shields.io/pypi/v/squishyplanet)
 [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

A package for modeling non-spherical exoplanets.

![image](docs/_static/media/videos/_static/480p15/Banner_ManimCE_v0.17.3.gif)

## Documentation

The docs for ``squishyplanet`` are hosted on [Read the Docs](https://squishyplanet.readthedocs.io/en/latest/). See those for installation instructions, example usage, and API documentation.

## Installation

You can install ``squishyplanet`` from PyPI with pip:

```bash
python -m pip install squishyplanet
```

See the [installation instructions](https://squishyplanet.readthedocs.io/en/latest/installation.html) for more details.

## Attribution and License


``squishyplanet`` is made freely available under the MIT License. If you use this code in your research, please cite the accompanying JOSS paper:

```
@article{squishyplanet,
   author = {{Cassese}, Ben and {Vega}, Justin and {Lu}, Tiger and {Rice}, Malena and {Poddar}, Avishi and {Kipping}, David},
   doi = {10.21105/joss.06972},
   journal = {Journal of Open Source Software},
   month = aug,
   number = {100},
   pages = {6972},
   title = {{squishyplanet: modeling transits of non-spherical exoplanets in JAX}},
   url = {https://joss.theoj.org/papers/10.21105/joss.06972},
   volume = {9},
   year = {2024}
}
```

==> squishyplanet-0.3.1.tar.gz: squishyplanet-0.3.1/README.md <==
# squishyplanet

[![DOI](https://joss.theoj.org/papers/10.21105/joss.06972/status.svg)](https://doi.org/10.21105/joss.06972)
[![Documentation Status](https://readthedocs.org/projects/squishyplanet/badge/?version=latest)](https://squishyplanet.readthedocs.io/en/latest/?badge=latest)
![Build Status](https://github.com/ben-cassese/squishyplanet/actions/workflows/tests.yml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/ben-cassese/squishyplanet/badge.svg?branch=main&service=github)](https://coveralls.io/github/ben-cassese/squishyplanet?branch=main)
![PyPI - Version](https://img.shields.io/pypi/v/squishyplanet)
 [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)

A package for modeling non-spherical exoplanets.

![image](docs/_static/media/videos/_static/480p15/Banner_ManimCE_v0.17.3.gif)

## Documentation

The docs for ``squishyplanet`` are hosted on [Read the Docs](https://squishyplanet.readthedocs.io/en/latest/). See those for installation instructions, example usage, and API documentation.

## Installation

You can install ``squishyplanet`` from PyPI with pip:

```bash
python -m pip install squishyplanet
```

See the [installation instructions](https://squishyplanet.readthedocs.io/en/latest/installation.html) for more details.

## Attribution and License


``squishyplanet`` is made freely available under the MIT License. If you use this code in your research, please cite the accompanying JOSS paper:

```
@article{squishyplanet,
       author = {{Cassese}, Ben and {Vega}, Justin and {Lu}, Tiger and {Rice}, Malena and {Poddar}, Avishi and {Kipping}, David},
        title = "{squishyplanet: modeling transits of non-spherical exoplanets in JAX}",
      journal = {The Journal of Open Source Software},
     keywords = {astronomy, exoplanets, exoplanet transits, Python, Jupyter Notebook, Astrophysics - Instrumentation and Methods for Astrophysics, Astrophysics - Earth and Planetary Astrophysics},
         year = 2024,
        month = aug,
       volume = {9},
       number = {100},
          eid = {6972},
        pages = {6972},
          doi = {10.21105/joss.06972},
archivePrefix = {arXiv},
       eprint = {2409.00167},
 primaryClass = {astro-ph.IM},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2024JOSS....9.6972C},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```
